@@ -84,8 +84,8 @@ export const test_genericPolicyGovernance = (confFilePolicy, confFileViolationsI
     // Currently this is controlled using STANDALONE_TESTSUITE_EXECUTION variable
     it('Wait for cluster violation status to become available', () => {
       // switch to the Clusters tab
-      cy.get('#grc-cluster-view').click()
-        .then(() => {
+      cy.waitUntil(() => cy.get('#grc-cluster-view').scrollIntoView().should('be.visible'))
+      cy.get('#grc-cluster-view').scrollIntoView().should('be.visible').click().then(() => {
           if (Cypress.env('STANDALONE_TESTSUITE_EXECUTION') !== 'FALSE') {
             cy.waitForClusterViolationsStatus(clusterName, violationCounter)
           } else {
@@ -119,7 +119,7 @@ export const test_genericPolicyGovernance = (confFilePolicy, confFileViolationsI
     })
 
     it(`Verify policy ${policyName} violations at the Status - Clusters page`, () => {
-      cy.visit(`/multicloud/policies/all/${confPolicies[policyName]['namespace']}/${policyName}/status`).waitForPageContentLoad()
+      cy.visit(`/multicloud/policies/all/${confPolicies[policyName]['namespace']}/${policyName}/clusters`).waitForPageContentLoad()
       // verify all violations per cluster
       cy.waitForClusterTemplateStatus(clusterViolations)
         .verifyViolationsInPolicyStatusClusters(policyName, confPolicies[policyName], clusterViolations, confViolationPatterns)
@@ -127,21 +127,13 @@ export const test_genericPolicyGovernance = (confFilePolicy, confFileViolationsI
 
     it(`Verify policy ${policyName} violations at the Status - Templates page`, () => {
       // open the Templates tab - we should have a command for this
-      cy.get('#policy-status-templates').click()
+      cy.waitUntil(() => cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Templates').scrollIntoView().should('be.visible'))
+
+      cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Templates').scrollIntoView().should('be.visible').click()
+        .waitForPageContentLoad()
       // verify violations per template
         .verifyViolationsInPolicyStatusTemplates(policyName, confPolicies[policyName], clusterViolations, confViolationPatterns)
     })
-
-    // for (const clusterName of clusterList) {
-    //   it(`Verify policy details & templates on cluster ${clusterName} detailed page`, () => {
-    //     cy.visit(`/multicloud/policies/all/${confPolicies[policyName]['namespace']}/${policyName}`).waitForPageContentLoad()
-    //     cy.goToPolicyClusterPage(policyName, confPolicies[policyName], clusterName)
-    //       .verifyPolicyDetailsInCluster(policyName, confPolicies[policyName], clusterName, clusterViolations, confViolationPatterns)
-    //       .verifyPolicyTemplatesInCluster(policyName, confPolicies[policyName], clusterName, clusterViolations)
-    //       .verifyPolicyViolationDetailsInCluster(policyName, confPolicies[policyName], clusterName, clusterViolations, confViolationPatterns)
-    //   })
-    // }
-
   }
 
   // run the test for enforced policy only if the config file was given
@@ -188,7 +180,8 @@ export const test_genericPolicyGovernance = (confFilePolicy, confFileViolationsI
         // Currently this is controlled using STANDALONE_TESTSUITE_EXECUTION variable
         it('Wait for cluster violation status to become available', () => {
           // switch to the Clusters tab
-          cy.get('#grc-cluster-view').click()
+          cy.waitUntil(() => cy.get('#grc-cluster-view').scrollIntoView().should('be.visible'))
+          cy.get('#grc-cluster-view').scrollIntoView().should('be.visible').click()
             .then(() => {
               if (Cypress.env('STANDALONE_TESTSUITE_EXECUTION') !== 'FALSE') {
                 cy.waitForClusterViolationsStatus(clusterName, violationCounter)
@@ -215,7 +208,7 @@ export const test_genericPolicyGovernance = (confFilePolicy, confFileViolationsI
       })
 
       it(`Verify policy ${policyName} violations at the Status - Clusters page`, () => {
-        cy.visit(`/multicloud/policies/all/${confPolicies[policyName]['namespace']}/${policyName}/status`).waitForPageContentLoad()
+        cy.visit(`/multicloud/policies/all/${confPolicies[policyName]['namespace']}/${policyName}/clusters`).waitForPageContentLoad()
         // verify all violations per cluster
         cy.waitForClusterTemplateStatus(clusterViolations)
           .verifyViolationsInPolicyStatusClusters(policyName, confPolicies[policyName], clusterViolations, confViolationPatterns)
@@ -223,21 +216,13 @@ export const test_genericPolicyGovernance = (confFilePolicy, confFileViolationsI
 
       it(`Verify policy ${policyName} violations at the Status - Templates page`, () => {
         // open the Templates tab - we should have a command for this
-        cy.get('#policy-status-templates').click()
+        cy.waitUntil(() => cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Templates').scrollIntoView().should('be.visible'))
+
+        cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Templates').scrollIntoView().should('be.visible').click()
+          .waitForPageContentLoad()
         // verify violations per template
           .verifyViolationsInPolicyStatusTemplates(policyName, confPolicies[policyName], clusterViolations, confViolationPatterns)
       })
-
-      // for (const clusterName of clusterList) {
-      //   it(`Verify policy details & templates on cluster ${clusterName} detailed page`, () => {
-      //     cy.visit(`/multicloud/policies/all/${confPolicies[policyName]['namespace']}/${policyName}`).waitForPageContentLoad()
-      //     cy.goToPolicyClusterPage(policyName, confPolicies[policyName], clusterName)
-      //       .verifyPolicyDetailsInCluster(policyName, confPolicies[policyName], clusterName, clusterViolations, confViolationPatterns)
-      //       .verifyPolicyTemplatesInCluster(policyName, confPolicies[policyName], clusterName, clusterViolations)
-      //       .verifyPolicyViolationDetailsInCluster(policyName, confPolicies[policyName], clusterName, clusterViolations, confViolationPatterns)
-      //   })
-      // }
-
     }
   }
 
@@ -372,16 +357,20 @@ export const test_userPermissionsPageContentCheck = (userName, userPassword, IDP
         .checkDetailedPolicyPageUserPermissions(firstPolicyName, permissions)
     })
 
-    it(`Check ${firstPolicyName} policy Status page as ${userName}`, () => {
-      // click on Status tab
-      cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Status').click().waitForPageContentLoad()
+    it(`Check ${firstPolicyName} policy Clusters page as ${userName}`, () => {
+      // click on Clusters tab
+      cy.waitUntil(() => cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Clusters').scrollIntoView().should('be.visible'))
+      cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Clusters').scrollIntoView().should('be.visible').click()
+        .waitForPageContentLoad()
         // check permissions
         .checkPolicyStatusPageUserPermissions(firstPolicyName, permissions, namespaced)
         // check Templates tab only for a non-namespaced user
         .then(() => {
           if (!namespaced) {
             // click on Templates tab
-            cy.get('#policy-status-templates').click().waitForPageContentLoad()
+            cy.waitUntil(() => cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Templates').scrollIntoView().should('be.visible'))
+            cy.get('.pf-c-page__main-nav .pf-c-nav__link').contains('Templates').scrollIntoView().should('be.visible').click()
+              .waitForPageContentLoad()
               .checkPolicyStatusPageUserPermissions(firstPolicyName, permissions, namespaced, 3)
           }
         })
@@ -389,7 +378,7 @@ export const test_userPermissionsPageContentCheck = (userName, userPassword, IDP
 
     it(`Check ${firstPolicyName} policy edit page as ${userName}`, () => {
       return cy.url().then((pageURL) => {
-        const editPageURL = pageURL.replace('/status', '/edit')
+        const editPageURL = pageURL.replace(/\/clusters|\/templates/, '/edit')
         cy.visit(editPageURL).waitForPageContentLoad()
         if (permissions.patch) {
           cy.url().should('eq', editPageURL)
@@ -408,7 +397,9 @@ export const test_userPermissionsPageContentCheck = (userName, userPassword, IDP
     if (permissions.create || elevated) {
       // Check that specified namespaces are visible
       cy.get('button[aria-label="namespace"]').as('dropdown')
-      cy.get('@dropdown').click().parent().next().within(() => {
+      cy.waitUntil(() => cy.get('@dropdown').scrollIntoView().should('be.visible'))
+      cy.get('@dropdown').scrollIntoView().should('be.visible').click()
+        .parent().next().within(() => {
         for (const namespace of namespaces) {
           cy.get('li.pf-c-select__menu-wrapper').contains(new RegExp(`^${namespace}$`))
         }
@@ -424,7 +415,8 @@ export const test_userPermissionsPageContentCheck = (userName, userPassword, IDP
         })
       })
       // collapse the drop down again
-      cy.get('@dropdown').click()
+      cy.waitUntil(() => cy.get('@dropdown').scrollIntoView().should('be.visible'))
+      cy.get('@dropdown').scrollIntoView().should('be.visible').click()
       // now create a test policy
       cy.createPolicyFromSelection(newPolicyName, true, newPolicyConf)
       .verifyPolicyInListing(newPolicyName, newPolicyConf, 'disabled')
