@@ -3,10 +3,9 @@ import styles from '@patternfly/react-styles/css/components/Select/select';
 import formStyles from '@patternfly/react-styles/css/components/Form/form';
 import { css } from '@patternfly/react-styles';
 import { SelectOptionObject, SelectOption } from './SelectOption';
-import { SelectConsumer, SelectVariant } from './selectConstants';
+import { SelectConsumer, SelectVariant, SelectContextInterface } from './selectConstants';
 import { PickOptional } from '../../helpers/typeUtils';
 
-import { FocusTrap } from '../../helpers';
 import { SelectGroup } from './SelectGroup';
 import { Divider } from '../Divider/Divider';
 
@@ -25,7 +24,7 @@ export interface SelectMenuProps extends Omit<React.HTMLProps<HTMLElement>, 'che
   selected?: string | SelectOptionObject | (string | SelectOptionObject)[];
   /** Currently checked options (for checkbox variant) */
   checked?: (string | SelectOptionObject)[];
-  /** Internal flag for specifiying how the menu was opened */
+  /** @hide Internal flag for specifiying how the menu was opened */
   openedOnEnter?: boolean;
   /** Flag to specify the  maximum height of the menu, as a string percentage or number of pixels */
   maxHeight?: string | number;
@@ -33,13 +32,19 @@ export interface SelectMenuProps extends Omit<React.HTMLProps<HTMLElement>, 'che
   noResultsFoundText?: string;
   /** Inner prop passed from parent */
   createText?: string;
-  /** Internal callback for ref tracking */
+  /** @hide Internal callback for ref tracking */
   sendRef?: (ref: React.ReactNode, favoriteRef: React.ReactNode, index: number) => void;
-  /** Internal callback for keyboard navigation */
+  /** @hide Internal callback for keyboard navigation */
   keyHandler?: (index: number, innerIndex: number, position: string) => void;
   /** Flag indicating select has an inline text input for filtering */
   hasInlineFilter?: boolean;
   innerRef?: any;
+  /** Content rendered in the footer of the select menu */
+  footer?: React.ReactNode;
+  /** The menu footer element */
+  footerRef?: React.RefObject<HTMLDivElement>;
+  /** @hide callback to check if option is the last one in the menu when there is a footer  */
+  isLastOptionBeforeFooter?: (index: number) => void;
 }
 
 class SelectMenuWithRef extends React.Component<SelectMenuProps> {
@@ -54,14 +59,15 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
     sendRef: () => {},
     keyHandler: () => {},
     isCustomContent: false,
-    hasInlineFilter: false
+    hasInlineFilter: false,
+    isLastOptionBeforeFooter: () => {}
   };
 
   extendChildren(randomId: string) {
-    const { children, isGrouped } = this.props;
+    const { children, hasInlineFilter, isGrouped } = this.props;
     const childrenArray: React.ReactElement[] = children as React.ReactElement[];
+    let index = hasInlineFilter ? 1 : 0;
     if (isGrouped) {
-      let index = 0;
       return React.Children.map(childrenArray, (group: React.ReactElement) => {
         if (group.type === SelectGroup) {
           return React.cloneElement(group, {
@@ -75,9 +81,7 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
         }
       });
     }
-    return React.Children.map(childrenArray, (child: React.ReactElement, index: number) =>
-      this.cloneOption(child, index, randomId)
-    );
+    return React.Children.map(childrenArray, (child: React.ReactElement) => this.cloneOption(child, index++, randomId));
   }
 
   cloneOption(child: React.ReactElement, index: number, randomId: string) {
@@ -99,12 +103,11 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
     valueToCheck: string | SelectOptionObject,
     options: string | SelectOptionObject | (string | SelectOptionObject)[]
   ) {
-    if (!options) {
+    if (!options || !valueToCheck) {
       return false;
     }
 
     const isSelectOptionObject =
-      valueToCheck !== undefined &&
       typeof valueToCheck !== 'string' &&
       (valueToCheck as SelectOptionObject).toString &&
       (valueToCheck as SelectOptionObject).compareTo;
@@ -125,7 +128,7 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
   }
 
   extendCheckboxChildren(children: React.ReactElement[]) {
-    const { isGrouped, checked, sendRef, keyHandler, hasInlineFilter } = this.props;
+    const { isGrouped, checked, sendRef, keyHandler, hasInlineFilter, isLastOptionBeforeFooter } = this.props;
     let index = hasInlineFilter ? 1 : 0;
     if (isGrouped) {
       return React.Children.map(children, (group: React.ReactElement) => {
@@ -134,7 +137,7 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
         }
         return React.cloneElement(group, {
           titleId: group.props.label && group.props.label.replace(/\W/g, '-'),
-          children: (
+          children: group.props.children ? (
             <fieldset
               aria-labelledby={group.props.label && group.props.label.replace(/\W/g, '-')}
               className={css(styles.selectMenuFieldset)}
@@ -150,7 +153,7 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
                     })
               )}
             </fieldset>
-          )
+          ) : null
         });
       });
     }
@@ -161,12 +164,13 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
             isChecked: this.checkForValue(child.props.value, checked),
             sendRef,
             keyHandler,
-            index: index++
+            index: index++,
+            isLastOptionBeforeFooter
           })
     );
   }
 
-  render() {
+  renderSelectMenu({ variant, inputIdPrefix }: SelectContextInterface) {
     /* eslint-disable @typescript-eslint/no-unused-vars */
     const {
       children,
@@ -186,83 +190,65 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
       'aria-labelledby': ariaLabelledBy,
       hasInlineFilter,
       innerRef,
+      footer,
+      footerRef,
+      isLastOptionBeforeFooter,
       ...props
     } = this.props;
     /* eslint-enable @typescript-eslint/no-unused-vars */
+    let Component = 'div';
+    const variantProps = {
+      ref: innerRef,
+      className: css(!footer ? styles.selectMenu : 'pf-c-select__menu-list', className),
+      ...(maxHeight && { style: { maxHeight, overflow: 'auto' } })
+    } as React.HTMLAttributes<HTMLElement>;
+    const extendedChildren = () =>
+      variant === SelectVariant.checkbox
+        ? this.extendCheckboxChildren(children as React.ReactElement[])
+        : this.extendChildren(inputIdPrefix);
+
+    if (isCustomContent) {
+      variantProps.children = children;
+    } else if (hasInlineFilter) {
+      if (React.Children.count(children) === 0) {
+        variantProps.children = <fieldset className={css(styles.selectMenuFieldset)} />;
+      } else {
+        variantProps.children = (
+          <fieldset
+            aria-label={ariaLabel}
+            aria-labelledby={(!ariaLabel && ariaLabelledBy) || null}
+            className={css(formStyles.formFieldset)}
+          >
+            {(children as React.ReactElement[]).shift()}
+            {extendedChildren()}
+          </fieldset>
+        );
+      }
+    } else {
+      variantProps.children = extendedChildren();
+      if (!isGrouped) {
+        Component = 'ul';
+        variantProps.role = 'listbox';
+        variantProps['aria-label'] = ariaLabel;
+        variantProps['aria-labelledby'] = (!ariaLabel && ariaLabelledBy) || null;
+      }
+    }
+
     return (
-      <SelectConsumer>
-        {({ variant, inputIdPrefix }) => (
-          <React.Fragment>
-            {isCustomContent && (
-              <div
-                ref={innerRef}
-                className={css(styles.selectMenu, className)}
-                {...(maxHeight && { style: { maxHeight, overflow: 'auto' } })}
-                {...props}
-              >
-                {children}
-              </div>
-            )}
-            {variant !== SelectVariant.checkbox &&
-              !isCustomContent &&
-              (!isGrouped ? (
-                <ul
-                  ref={innerRef}
-                  className={css(styles.selectMenu, className)}
-                  role="listbox"
-                  aria-label={ariaLabel}
-                  aria-labelledby={(!ariaLabel && ariaLabelledBy) || null}
-                  {...(maxHeight && { style: { maxHeight, overflow: 'auto' } })}
-                  {...props}
-                >
-                  {this.extendChildren(inputIdPrefix)}
-                </ul>
-              ) : (
-                <div
-                  ref={innerRef}
-                  className={css(styles.selectMenu, className)}
-                  {...(maxHeight && { style: { maxHeight, overflow: 'auto' } })}
-                  {...props}
-                >
-                  {this.extendChildren(inputIdPrefix)}
-                </div>
-              ))}
-            {variant === SelectVariant.checkbox && !isCustomContent && React.Children.count(children) > 0 && (
-              <FocusTrap focusTrapOptions={{ clickOutsideDeactivates: true }}>
-                <div
-                  ref={innerRef}
-                  className={css(styles.selectMenu, className)}
-                  {...(maxHeight && { style: { maxHeight, overflow: 'auto' } })}
-                >
-                  <fieldset
-                    {...props}
-                    aria-label={ariaLabel}
-                    aria-labelledby={(!ariaLabel && ariaLabelledBy) || null}
-                    className={css(formStyles.formFieldset)}
-                  >
-                    {hasInlineFilter && [
-                      (children as React.ReactElement[]).shift(),
-                      ...this.extendCheckboxChildren(children as React.ReactElement[])
-                    ]}
-                    {!hasInlineFilter && this.extendCheckboxChildren(children as React.ReactElement[])}
-                  </fieldset>
-                </div>
-              </FocusTrap>
-            )}
-            {variant === SelectVariant.checkbox && !isCustomContent && React.Children.count(children) === 0 && (
-              <div
-                ref={innerRef}
-                className={css(styles.selectMenu, className)}
-                {...(maxHeight && { style: { maxHeight, overflow: 'auto' } })}
-              >
-                <fieldset className={css(styles.selectMenuFieldset)} />
-              </div>
-            )}
-          </React.Fragment>
+      <React.Fragment>
+        <Component {...variantProps} {...props} />
+        {footer && (
+          <div className={css(styles.selectMenuFooter)} ref={footerRef}>
+            {footer}
+          </div>
         )}
-      </SelectConsumer>
+      </React.Fragment>
     );
   }
+
+  render() {
+    return <SelectConsumer>{context => this.renderSelectMenu(context)}</SelectConsumer>;
+  }
 }
 
 export const SelectMenu = React.forwardRef((props, ref) => (
